@@ -57,8 +57,8 @@ struct _Conversion {
 	IMAGE *mask;		/* Read display mask from here */
 	Imageinfo *repaint_ii;	/* Colour converted for screen */
 	REGION *ireg;		/* Region for input from repaint image */
+	REGION *mreg;		/* Region for input from repaint mask */
 	int tile_size;		/* Set smaller for thumbnails */
-	int fade_steps;		/* Set to 1 for thumbnails */
 
 	/* Basic geometry.
 	 */
