@@ -768,20 +768,6 @@ filesel_get_filename( Filesel *filesel )
 	return( name );
 }
 
-/* How many selected filenames.
- */
-int
-filesel_nselected( Filesel *filesel )
-{
-	GSList *names = gtk_file_chooser_get_filenames( 
-		GTK_FILE_CHOOSER( filesel->chooser ) );
-	int n = g_slist_length( names );
-
-	IM_FREEF( slist_free_all, names );
-
-	return( n );
-}
-
 /* Get filename multi ... map over the selected filenames.
  */
 void *
@@ -854,10 +840,7 @@ filesel_update_preview_cb( GtkFileChooser *chooser, Filesel *filesel )
 
 	if( (filename = gtk_file_chooser_get_preview_filename(
 		GTK_FILE_CHOOSER( filesel->chooser ) )) ) {
-		gtk_file_chooser_set_preview_widget_active(
-			GTK_FILE_CHOOSER( filesel->chooser ),
-			preview_set_filename( filesel->preview, filename ) );
-
+		preview_set_filename( filesel->preview, filename );
 		g_free( filename );
 	}
 }
@@ -1006,6 +989,8 @@ filesel_build( GtkWidget *widget )
 			"update-preview",
 			GTK_SIGNAL_FUNC( filesel_update_preview_cb ), filesel );
 		gtk_widget_show( GTK_WIDGET( filesel->preview ) );
+		gtk_file_chooser_set_preview_widget_active(
+			GTK_FILE_CHOOSER( filesel->chooser ), TRUE );
 	}
 
 	if( filesel_last_dir ) 
