@@ -132,6 +132,7 @@ imagemodel_dispose( GObject *gobject )
 	IM_FREE( imagemodel->font_name );
 	IM_FREE( imagemodel->text );
 	MANAGED_UNREF( imagemodel->text_mask );
+	MANAGED_UNREF( imagemodel->nib );
 
 	G_OBJECT_CLASS( parent_class )->dispose( gobject );
 }
@@ -251,7 +252,8 @@ imagemodel_refresh_ink( Imagemodel *imagemodel, Imageinfo *ii )
 static void
 imagemodel_conv_changed_cb( Conversion *conv, Imagemodel *imagemodel )
 {
-	imagemodel_refresh_ink( imagemodel, conv->ii );
+	if( conv->ii )
+		imagemodel_refresh_ink( imagemodel, conv->ii );
 
 	iobject_changed( IOBJECT( imagemodel ) );
 }
@@ -290,7 +292,8 @@ imagemodel_init( Imagemodel *imagemodel )
 	imagemodel->show_status = DISPLAY_STATUS;
 
 	imagemodel->show_paintbox = FALSE;
-	imagemodel->nib = PAINTBOX_1ROUND;
+	imagemodel->nib_radius = 0;
+	imagemodel->nib = NULL;
 	imagemodel->ink = NULL;
 	imagemodel->font_name = im_strdup( NULL, PAINTBOX_FONT );
 	imagemodel->text = NULL;
@@ -373,7 +376,9 @@ imagemodel_new( iImage *iimage )
 	Imagemodel *imagemodel;
 
 	imagemodel = g_object_new( TYPE_IMAGEMODEL, NULL );
-	imagemodel_link( imagemodel, iimage );
+
+	if( iimage )
+		imagemodel_link( imagemodel, iimage );
 
 #ifdef DEBUG
 	printf( "imagemodel_new: " );
@@ -524,6 +529,23 @@ imagemodel_refresh_text( Imagemodel *imagemodel )
 	return( TRUE );
 }
 
+gboolean
+imagemodel_refresh_nib( Imagemodel *imagemodel )
+{
+	MANAGED_UNREF( imagemodel->nib );
+
+	if( !(imagemodel->nib = imageinfo_new_temp( main_imageinfogroup, 
+			reduce_context->heap, NULL, "t" )) ) 
+		return( FALSE );
+
+	MANAGED_REF( imagemodel->nib );
+
+	if( !imageinfo_paint_nib( imagemodel->nib, imagemodel->nib_radius ) )
+		return( FALSE );
+
+	return( TRUE );
+}
+
 /* After a paint action: mark all subsequent things dirty, recalc if prefs say
  * so.
  */
