@@ -49,8 +49,8 @@
 /* But some themes can trigger warnings, argh, so sometimes we need to
  * undef it. VipsObject sets can trigger warnings. libgoffice will warn about
  * precision issues if run under valgrind.
- */
 #undef DEBUG_FATAL
+ */
 
 /* Time startup.
 #define DEBUG_TIME
@@ -63,6 +63,11 @@
 #define PROFILE
  */
 
+/* Sometimes we need to be able to disable these at build time.
+#undef DEBUG_FATAL
+#undef DEBUG_LEAK
+ */
+
 /* Need im__print_all() for leak testing.
  */
 #ifdef DEBUG_LEAK
@@ -87,7 +92,6 @@ gboolean main_starting = TRUE;			/* In startup */
 static const char *main_argv0 = NULL;		/* argv[0] */
 static iOpenFile *main_stdin = NULL;		/* stdin as an iOpenFile */
 static GtkIconFactory *main_icon_factory = NULL;/* Add stocks to this */
-static Splash *main_splash = NULL;
 
 static char *main_option_script = NULL;
 static char *main_option_expression = NULL;
@@ -356,7 +360,7 @@ main_quit( void )
 	im__print_all();
 	managed_check_all_destroyed();
 	util_check_all_destroyed();
-	vips_check_all_destroyed();
+	call_check_all_destroyed();
 
 #ifdef PROFILE
 	g_mem_profile();
@@ -421,13 +425,6 @@ main_quit_test( void )
 		main_quit_test_cb, NULL );
 }
 
-gboolean
-main_splash_enabled( void )
-{
-	return( !existsf( "%s" G_DIR_SEPARATOR_S "%s", 
-		get_savedir(), NO_SPLASH ) );
-}
-
 static void
 main_watchgroup_changed_cb( void )
 {
@@ -470,7 +467,7 @@ main_load( Workspace *ws, const char *filename )
 
 	/* Try as matrix or image. Have to do these via definitions.
 	 */
-	if( workspace_load_file( ws, filename ) )
+	if( workspace_load_file( ws, filename ) ) 
 		return( TRUE );
 
 	error_clear();
@@ -549,7 +546,7 @@ main_link_package( im_package *pack)
 	kit = toolkit_new( main_toolkitgroup, name );
 
         for( i = 0; i < pack->nfuncs; i++ ) 
-		if( vips_is_callable( pack->table[i] ) ) {
+		if( call_is_callable( pack->table[i] ) ) {
 			Symbol *sym;
 
 			sym = symbol_new( symbol_root->expr->compile,
@@ -557,7 +554,7 @@ main_link_package( im_package *pack)
 			g_assert( sym->type == SYM_ZOMBIE );
 			sym->type = SYM_EXTERNAL;
 			sym->function = pack->table[i];
-			sym->fn_nargs = vips_n_args( pack->table[i] );
+			sym->fn_nargs = call_n_args( pack->table[i] );
 			(void) tool_new_sym( kit, -1, sym );
 			symbol_made( sym );
 		}
@@ -812,8 +809,7 @@ main_x_init( int *argc, char ***argv )
 	gtk_window_set_default_icon_from_file( buf, NULL );
 
 	/* Turn off startup notification. Startup is done when we pop our
-	 * first window, not when we make this secret window or display the
-	 * splash screen.
+	 * first window, not when we make this secret window.
 	 */
 	gtk_window_set_auto_startup_notification( FALSE );
 
@@ -831,17 +827,6 @@ main_x_init( int *argc, char ***argv )
 
 	main_register_icons();
 
-	if( main_splash_enabled() ) {
-		main_splash = splash_new();
-		gtk_widget_show( GTK_WIDGET( main_splash ) );
-
-		/* Wait for the splashscreen to pop up. We want this to appear
-		 * as quickly as possible.
-		 */
-		while( g_main_context_iteration( NULL, FALSE ) )
-			;
-	}
-
 	/* Next window we make is end of startup.
 	 */
 	gtk_window_set_auto_startup_notification( TRUE );
@@ -866,14 +851,18 @@ static void
 main_toobig_done( iWindow *iwnd, 
 	void *client, iWindowNotifyFn nfn, void *sys )
 {
-	/* Don't "rm *", too dangerous. There can (I think?) only be ws and
-	 * VIPS files.
+	/* Don't "rm *", too dangerous. 
 	 */
 	path_map_dir( PATH_TMP, "*.v",
 		(path_map_fn) main_toobig_done_sub, NULL );
 	path_map_dir( PATH_TMP, "*.ws",
 		(path_map_fn) main_toobig_done_sub, NULL );
 
+	/* _stdenv.def:magick can generate .tif files.
+	 */
+	path_map_dir( PATH_TMP, "*.tif",
+		(path_map_fn) main_toobig_done_sub, NULL );
+
 	/* Tell space-free indicators to update.
 	 */
 	if( main_imageinfogroup )
@@ -1076,6 +1065,10 @@ main( int argc, char *argv[] )
 	 */
 	setenvf( "SEP", "%s", G_DIR_SEPARATOR_S );
 
+	/* Executable file extension (eg. ".exe" on Windows).
+	 */
+	setenvf( "EXEEXT", "%s", VIPS_EXEEXT );
+
 	/* Start up vips.
 	 */
 	if( im_init_world( main_argv0 ) )
@@ -1435,8 +1428,6 @@ main( int argc, char *argv[] )
 				main_log_add( "%s\n", error_get_sub() );
 	}
 
-	symbol_recalculate_all_force( TRUE );
-
 	/* Make sure our start ws doesn't have modified set. We may have
 	 * loaded some images or whatever into it.
 	 */
@@ -1467,11 +1458,6 @@ main( int argc, char *argv[] )
 		while( g_main_context_iteration( NULL, FALSE ) )
 			;
 
-		if( main_splash ) {
-			gtk_widget_destroy( GTK_WIDGET( main_splash ) );
-			main_splash = NULL;
-		}
-
 		if( !main_log_is_empty() ) {
 			error_top( _( "Startup error." ) );
 			error_sub( _( "Startup error log:\n%s" ), 
@@ -1510,6 +1496,10 @@ _( "A new directory has been created to hold startup, "
 		 */
 		main_starting = FALSE;
 
+		/* Make sure we have a recalc queued.
+		 */
+		symbol_recalculate_all_force( FALSE );
+
 		gtk_main();
 	}
 
