@@ -616,7 +616,8 @@ mainw_space_free_tooltip_generate( GtkWidget *widget, VipsBuf *buf,
 		g_slist_length( ICONTAINER( sym->expr->compile )->children ) );
         vips_buf_appends( buf, ", " );
 
-        vips_buf_appendf( buf, _( "%d vips calls cached" ), vips_history_size );
+        vips_buf_appendf( buf, _( "%d vips calls cached" ), 
+		cache_history_size );
         vips_buf_appends( buf, ", " );
 
         vips_buf_appendf( buf, _( "using %d threads" ), im_concurrency_get() );
@@ -726,7 +727,7 @@ mainw_group_action_cb( GtkAction *action, Mainw *mainw )
 	vips_buf_appends( &buf, "Group [" );
 	workspace_selected_names( ws, &buf, "," );
 	vips_buf_appends( &buf, "]" );
-	if( !workspace_add_def( ws, vips_buf_all( &buf ) ) ) {
+	if( !workspace_add_def_recalc( ws, vips_buf_all( &buf ) ) ) {
 		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		return;
 	}
@@ -904,12 +905,6 @@ mainw_open_workspace( Workspacegroup *wsg, const char *filename )
 	gtk_widget_show( GTK_WIDGET( mainw ) );
 	mainw_recent_add( &mainw_recent_workspace, filename );
 
-	/* Process some events to make sure we rethink the layout and
-	 * are able to get the append-at-RHS offsets.
-	 */
-	while( g_main_context_iteration( NULL, FALSE ) )
-		;
-
 	symbol_recalculate_all();
 
 	return( ws );
@@ -1022,7 +1017,8 @@ mainw_open_done_cb( iWindow *iwnd, void *client,
 		else
 			vips_buf_appends( &buf2, vips_buf_all( &buf ) );
 
-		if( !workspace_add_def( mainw->ws, vips_buf_all( &buf2 ) ) ) {
+		if( !workspace_add_def_recalc( mainw->ws, 
+			vips_buf_all( &buf2 ) ) ) {
 			error_top( _( "Load failed." ) );
 			error_sub( _( "Unable to execute:\n   %s" ), 
 				vips_buf_all( &buf2 ) );
@@ -1242,8 +1238,7 @@ mainw_workspace_merge_fn( Filesel *filesel,
 	/* Process some events to make sure we rethink the layout and
 	 * are able to get the append-at-RHS offsets.
 	 */
-	while( g_main_context_iteration( NULL, FALSE ) )
-		;
+	process_events();
 
 	symbol_recalculate_all();
 	mainw_recent_add( &mainw_recent_workspace, filename );
@@ -1298,7 +1293,7 @@ mainw_workspace_duplicate_action_cb( GtkAction *action, Mainw *mainw )
 	Workspace *new_ws;
 	Mainw *new_mainw;
 
-        progress_begin();
+	progress_begin();
 
 	if( !(new_ws = workspace_clone( mainw->ws )) ) {
 		progress_end();
@@ -2233,9 +2228,7 @@ mainw_new( Workspace *ws )
 {
 	Mainw *mainw;
 
-	/* We must have calced before we build the view so we get menus etc.
-	 */
-	symbol_recalculate_all_force( TRUE );
+	symbol_recalculate_all_force( FALSE );
 
 	mainw = MAINW( g_object_new( TYPE_MAINW, NULL ) );
 	mainw_link( mainw, ws );
