@@ -146,7 +146,7 @@ struct _Reduce {
 	rc->fsps[rc->running] = rc->fsp; \
 	rc->tsp[rc->running] = trace_get_mark(); \
 	if( setjmp( rc->error[rc->running++] ) ) { \
-		assert( rc->running >= 0 ); \
+		g_assert( rc->running >= 0 ); \
 		rc->sp = rc->sps[rc->running]; \
 		rc->fsp = rc->fsps[rc->running]; \
 		trace_pop_to( rc->tsp[rc->running] ); \
@@ -159,7 +159,7 @@ struct _Reduce {
 #define REDUCE_CATCH_STOP \
 { \
 	rc->running -= 1; \
-	assert( rc->running >= 0 ); \
+	g_assert( rc->running >= 0 ); \
 }
 
 /* Util.
@@ -171,12 +171,17 @@ typedef void *(*reduce_safe_pointer_fn)( Reduce *rc, PElement *,
 void *reduce_safe_pointer( Reduce *rc, reduce_safe_pointer_fn fn, 
 	void *a, void *b, void *c, void *d );
 
+void reduce_get_list( Reduce *rc, PElement *list );
 void reduce_error_typecheck( Reduce *rc, 
 	PElement *e, const char *name, const char *type );
 typedef void *(*reduce_map_list_fn)( Reduce *rc,
 	PElement *, void *, void * );
 void *reduce_map_list( Reduce *rc, 
 	PElement *base, reduce_map_list_fn fn, void *a, void *b );
+typedef void *(*reduce_map_dict_fn)( Reduce *, 
+	const char *, PElement *, void *a, void *b );
+void *reduce_map_dict( Reduce *rc, 
+	PElement *base, reduce_map_dict_fn fn, void *a, void *b );
 void reduce_clone_list( Reduce *rc, PElement *base, PElement *out );
 int reduce_get_string( Reduce *rc, PElement *base, char *buf, int n );
 int reduce_get_lstring( Reduce *rc, PElement *base, GSList **labels );
