@@ -119,7 +119,9 @@ typedef struct _ToolClass {
 	 */
 } ToolClass;
 
-void tool_error( Tool *tool, BufInfo *buf );
+void tool_error( Tool *tool, VipsBuf *buf );
+
+void *tool_linkreport_tool( Tool *tool, VipsBuf *buf, gboolean *found );
 
 GType tool_get_type( void );
 
