@@ -72,10 +72,9 @@ toolkitbrowser_rebuild_item3( Toolitem *toolitem,
 		!toolitem->is_separator &&
 		toolitem->compile ) {
 		char txt[256];
-		VipsBuf buf;
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 		GtkTreeIter iter;
 
-		vips_buf_init_static( &buf, txt, 256 );
 		if( toolitem->action_sym && 
 			toolitem->action_sym->expr &&
 			toolitem->action_sym->expr->compile->param ) 
@@ -221,7 +220,8 @@ toolkitbrowser_row_activated_cb( GtkTreeView *treeview,
 	Toolkitbrowser *toolkitbrowser )
 {
 	if( !toolkitbrowser_activate_selected( toolkitbrowser ) )
-		box_alert( GTK_WIDGET( toolkitbrowser ) );
+		iwindow_alert( GTK_WIDGET( toolkitbrowser ), 
+			GTK_MESSAGE_ERROR );
 }
 
 static void
